@@ -109,6 +109,7 @@ private slots:
     bool getforward(bool setcolor);
     int cuttercount(QString row);
     int cutterint(QString row, QString sterm, int place);
+    QString getBTcon();
     QString getBTproperty(QString key);
     QString getBTdevPath();
     QString getlsof();
@@ -116,6 +117,9 @@ private slots:
     QString filterlog(QString linelog);
     QString cutter(QString row, QString cutstr, int place);
     QString getip(QString dev);
+    QString getleaseip(QString macadd);
+    void showleaseip(QString macadd);
+    void showconnections();
     QString cutsubnet(QString net);
     bool wmode(QString dev);
     QString getfilter(QString ftype);
@@ -214,6 +218,8 @@ private slots:
     void textcolorset(QColor);
     void bgtextcolorset(QColor);
 
+    void on_pushButton_clients_clicked();
+
 public slots:
     void helpaktion_button(bool act, bool forground);
 
