@@ -3,8 +3,9 @@
 
 #include <QDialog>
 
-namespace Ui {
-    class PWQDialog;
+namespace Ui
+{
+class PWQDialog;
 }
 
 class PWQDialog : public QDialog
@@ -16,7 +17,7 @@ public:
     ~PWQDialog();
 
 public slots:
-     void pwCheck();
+    void pwCheck();
 
 private:
     Ui::PWQDialog *ui;
